@@ -1,7 +1,7 @@
 /*
  *   Copyright (C) 2006
  *   Siraj Razick <siraj@kdemail.net>
- *   PhobosK <phobosk@mail.kbfx.org>
+ *   PhobosK <phobosk@mail.kbfx.net>
  *   see Also AUTHORS
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -26,9 +26,9 @@ KbfxConfig::KbfxConfig()
 	/* set default configuration values */
 
 	/* KBFX internal settings */
-	KbfxThemeRcDestination = KGlobal::dirs()->saveLocation ( "data", TQString ( "kbfx/themerc/" ), TRUE );
-	KbfxRcPath = KGlobal::dirs()->findResource ( "config", "kbfxrc" );
-	m_KbfxDeleteOldConf = FALSE;
+	KbfxThemeRcDestination = TDEGlobal::dirs()->saveLocation ( "data", TQString ( "kbfx/themerc/" ), true );
+	KbfxRcPath = TDEGlobal::dirs()->findResource ( "config", "kbfxrc" );
+	m_KbfxDeleteOldConf = false;
 	TQString _unspecified = tr2i18n ( "Not Specified" );
 	TQString path = locate ( "data", "kbfx/skins/default/bg.png" );
 	path.remove ( "default/bg.png" );
@@ -47,19 +47,19 @@ KbfxConfig::KbfxConfig()
 	m_UserSpinxThemeBasePathDefault = path;
 
 	m_KbfxMenuTypeDefault = "spinx";
-	m_ToolBarResizeDefault = FALSE;
-	m_KbfxWatcherDefault = TRUE;
-	m_KbfxShowOldThemesDefault = FALSE;
+	m_ToolBarResizeDefault = false;
+	m_KbfxWatcherDefault = true;
+	m_KbfxShowOldThemesDefault = false;
 
 	/* user(dude) image properties */
-	m_SpinxDudeBlinkDefault = FALSE;
+	m_SpinxDudeBlinkDefault = false;
 	KUser *user = new KUser();
 	m_SpinxDudeImageDefault = locate ( "data", user->homeDir () + "/.face.icon" );
 	delete user;
 
 	/* tooltip properties */
-	m_ToolTipDefault = FALSE;
-	m_ToolTipAnimationDefault = TRUE;
+	m_ToolTipDefault = false;
+	m_ToolTipAnimationDefault = true;
 	m_ToolTipTextDefault = "Application menu";
 	m_ToolTipAvatarDefault = path + "default/butterfly.png";
 	m_SpinxTooltipDudeboxDefault = path + "default/tooltip_dudebox.png";
@@ -87,7 +87,7 @@ KbfxConfig::KbfxConfig()
 	m_faceIconWDefault = 65;
 	m_userNamePos_xDefault  = 130;
 	m_userNamePos_yDefault = 32;
-	m_faceBoxHideTextDefault = FALSE;
+	m_faceBoxHideTextDefault = false;
 
 	/* top bar properties */
 	m_topBar_xDefault = 0;
@@ -118,7 +118,7 @@ KbfxConfig::KbfxConfig()
 	m_searchBox_wDefault = 240;
 	m_searchBox_xDefault = 130;
 	m_searchBox_yDefault = 48;
-	m_searchBox_staticDefault = TRUE;
+	m_searchBox_staticDefault = true;
 
 	/* item view properties */
 	m_itemView_hDefault = 380;
@@ -133,9 +133,9 @@ KbfxConfig::KbfxConfig()
 	/* KBFX misc properties */
 	m_userMenuHeightDefault = 513;
 	m_userMenuWidthDefault = 504;
-	m_startHiddenDefault = FALSE;
+	m_startHiddenDefault = false;
 	m_fadeTimeDefault = 75;
-	m_noCommentsDefault = FALSE;
+	m_noCommentsDefault = false;
 	m_commentMargineDefault = 66;
 	m_iconSizeDefault = 32;
 
@@ -155,7 +155,7 @@ KbfxConfig::KbfxConfig()
 	m_pluginNameColorDefault = TQColor ( 0,0,0 );
 	m_pluginNameFontDefault = TQFont ( "Arial", 8, TQFont::Normal );
 	m_lineColorDefault = TQColor ( 255,220,125 );
-	m_fontHoverBoldDefault = FALSE;
+	m_fontHoverBoldDefault = false;
 
 	/* set default theme info values */
 	m_InfoVersionDefault = _unspecified;
@@ -298,11 +298,11 @@ void KbfxConfig::readThemeInfo ( TQString &themePath, TQString &themeName )
 	setThemeInfoDefault();
 
 	TQFileInfo * info_theme =  new TQFileInfo ( themePath + themeName + "/" + m_KbfxThemesVersion );
-	KConfig * infoconfig = 0;
+	TDEConfig * infoconfig = 0;
 
-	if ( info_theme->exists() == TRUE )
+	if ( info_theme->exists() )
 	{
-		infoconfig = new KConfig ( info_theme->absFilePath() );
+		infoconfig = new TDEConfig ( info_theme->absFilePath() );
 		infoconfig->setGroup ( "ThemeGeneral" );
 		m_InfoVersion = infoconfig->readEntry ( "ThemeVersion", m_InfoVersionDefault );
 		m_InfoAuthor = infoconfig->readEntry ( "AuthorName", m_InfoAuthorDefault );
@@ -325,11 +325,11 @@ void KbfxConfig::readThemeInfo ( TQString &themePath, TQString &themeName )
 void KbfxConfig::read()
 {
 	/* read general configuration */
-	KConfigSkeleton *confskel = new KConfigSkeleton ( TQString::fromLatin1 ( "kbfxrc" ) );
+	TDEConfigSkeleton *confskel = new TDEConfigSkeleton ( TQString::fromLatin1 ( "kbfxrc" ) );
 
-	KConfig *conf = confskel->config();
+	TDEConfig *conf = confskel->config();
 
-	TQString __default = KGlobal::iconLoader()->iconPath ( "kbfx", ( int ) KIcon::Desktop, FALSE );
+	TQString __default = TDEGlobal::iconLoader()->iconPath ( "kbfx", ( int ) TDEIcon::Desktop, false );
 
 	conf->setGroup ( "KbfxGeneral" );
 	m_KbfxGeneralVersion = conf->readNumEntry ( "Version", 0 );
@@ -396,7 +396,7 @@ void KbfxConfig::read()
 	if ( m_KbfxGeneralVersion < m_KbfxGeneralVersionDefault )
 	{
 		m_KbfxGeneralVersion = m_KbfxGeneralVersionDefault;
-		m_KbfxDeleteOldConf = TRUE;
+		m_KbfxDeleteOldConf = true;
 	}
 }
 
@@ -414,20 +414,20 @@ void KbfxConfig::readFontrc ( TQString & themePath, TQString & themeName, bool u
 	TQString _abs_path = "";
 	TQFileInfo * info = new TQFileInfo ( themePath + themeName + "/kbfxfontrc" );
 	TQFileInfo * info_theme =  new TQFileInfo ( KbfxThemeRcDestination + "/" +  themeName + "_fontrc" );
-	KConfig * fontconfig = 0;
+	TDEConfig * fontconfig = 0;
 
 	/* if theme kbfxfontrc exists, make its configuration as default values - prefer users' configuration */
-	if ( info_theme->exists() == TRUE || info->exists() == TRUE )
+	if ( info_theme->exists() || info->exists() )
 	{
-		if ( info_theme->exists() == TRUE && m_KbfxGeneralVersion >= m_KbfxGeneralVersionDefault && user_rc )
+		if ( info_theme->exists() && m_KbfxGeneralVersion >= m_KbfxGeneralVersionDefault && user_rc )
 		{
 			_abs_path = info_theme->absFilePath();
 		}
-		else if ( info->exists() == TRUE || m_KbfxGeneralVersion < m_KbfxGeneralVersionDefault )
+		else if ( info->exists() || m_KbfxGeneralVersion < m_KbfxGeneralVersionDefault )
 		{
 			_abs_path = info->absFilePath();
 		}
-		fontconfig = new KConfig ( _abs_path );
+		fontconfig = new TDEConfig ( _abs_path );
 
 		fontconfig->setGroup ( "Fonts" );
 		m_fontTooltipColor = fontconfig->readColorEntry ( "TooltipText", &m_fontTooltipColorDefault );
@@ -499,11 +499,11 @@ void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool us
 	KbfxOffImg = TQPixmap ( KbfxPlasmaPixmapProvider::PixmapPath ( "off", themePath, themeName ) );
 
 	/* use theme's default dude image if any */
-	KConfigSkeleton *confskel = new KConfigSkeleton ( TQString::fromLatin1 ( "kbfxrc" ) );
-	KConfig *conf = confskel->config();
-	TQString __default = KGlobal::iconLoader()->iconPath ( "kbfx", ( int ) KIcon::Desktop, FALSE );
+	TDEConfigSkeleton *confskel = new TDEConfigSkeleton ( TQString::fromLatin1 ( "kbfxrc" ) );
+	TDEConfig *conf = confskel->config();
+	TQString __default = TDEGlobal::iconLoader()->iconPath ( "kbfx", ( int ) TDEIcon::Desktop, false );
 
-	if ( m_SpinxDudeImageDefault == TQString() || !KStandardDirs::exists ( m_SpinxDudeImageDefault ) )
+	if ( m_SpinxDudeImageDefault == TQString() || !TDEStandardDirs::exists ( m_SpinxDudeImageDefault ) )
 	{
 		m_SpinxDudeImageDefault = KbfxPlasmaPixmapProvider::PixmapPath ( "menu_top_image_person", themePath, themeName );
 	}
@@ -529,21 +529,21 @@ void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool us
 	TQString _abs_path = "";
 	TQFileInfo * info = new TQFileInfo ( themePath + themeName + "/kbfxlayoutrc" );
 	TQFileInfo * info_theme =  new TQFileInfo ( KbfxThemeRcDestination + "/" +  themeName + "_layoutrc" );
-	KConfig *layoutconfig = 0;
+	TDEConfig *layoutconfig = 0;
 
 	/* if theme kbfxlayoutrc exists, make its configuration as default values - prefer users' configuration */
-	if ( info_theme->exists() == TRUE || info->exists() == TRUE )
+	if ( info_theme->exists() || info->exists() )
 	{
-		if ( info_theme->exists() == TRUE && m_KbfxGeneralVersion >= m_KbfxGeneralVersionDefault && user_rc )
+		if ( info_theme->exists() && m_KbfxGeneralVersion >= m_KbfxGeneralVersionDefault && user_rc )
 		{
 			_abs_path = info_theme->absFilePath();
 		}
-		else if ( info->exists() == TRUE || m_KbfxGeneralVersion < m_KbfxGeneralVersionDefault )
+		else if ( info->exists() || m_KbfxGeneralVersion < m_KbfxGeneralVersionDefault )
 		{
 			_abs_path = info->absFilePath();
 		}
 
-		layoutconfig = new KConfig ( _abs_path );
+		layoutconfig = new TDEConfig ( _abs_path );
 
 		layoutconfig->setGroup ( "KbfxButton" );
 		m_KbfxNormalButtonPath = layoutconfig->readEntry ( "Normal", m_KbfxNormalButtonPathDefault );
@@ -702,13 +702,13 @@ void KbfxConfig::write()
 		kdDebug() << "Deleting general RC file: " << KbfxRcPath << endl;
 	}
 
-	KConfigSkeleton *confskel = new KConfigSkeleton ( TQString::fromLatin1 ( "kbfxrc" ) );
+	TDEConfigSkeleton *confskel = new TDEConfigSkeleton ( TQString::fromLatin1 ( "kbfxrc" ) );
 
 	/* write general KBFX configuration options */
-	KConfig *conf = confskel->config();
+	TDEConfig *conf = confskel->config();
 
 	conf->setGroup ( "KDE Action Restrictions" );
-	conf->writeEntry ( "warn_unwritable_config", FALSE );
+	conf->writeEntry ( "warn_unwritable_config", false );
 
 	conf->setGroup ( "KbfxGeneral" );
 	conf->writeEntry ( "Version", m_KbfxGeneralVersion );
@@ -746,7 +746,7 @@ void KbfxConfig::write()
 void KbfxConfig::writeFontrc ( TQString & themeName )
 {
 	/* write fonts KBFX configuration from theme name */
-	KConfig *fontconfig = new KConfig ( KbfxThemeRcDestination + "/" +  themeName + "_fontrc" );
+	TDEConfig *fontconfig = new TDEConfig ( KbfxThemeRcDestination + "/" +  themeName + "_fontrc" );
 
 	fontconfig->setGroup ( "Fonts" );
 	fontconfig->writeEntry ( "TooltipText", m_fontTooltipColor );
@@ -775,7 +775,7 @@ void KbfxConfig::writeThemerc ( TQString & themeName )
 	checkValues();
 
 	/* write layout theme configuration from theme name */
-	KConfig *layoutconfig = new KConfig ( KbfxThemeRcDestination + "/" +  themeName + "_layoutrc" );
+	TDEConfig *layoutconfig = new TDEConfig ( KbfxThemeRcDestination + "/" +  themeName + "_layoutrc" );
 
 	layoutconfig->setGroup ( "KbfxButton" );
 	layoutconfig->writeEntry ( "Normal", m_KbfxNormalButtonPath );
