@@ -29,7 +29,7 @@
 
 class KbfxPixmapLabel : public TQLabel
 {
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
