@@ -1,7 +1,7 @@
 /*
  *   Copyright (C) 2006
  *   Siraj Razick <siraj@kdemail.net>
- *   PhobosK <phobosk@mail.kbfx.org>
+ *   PhobosK <phobosk@mail.kbfx.net>
  *   see Also AUTHORS
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@ extern "C"
 {
 	KbfxDataStack * view();
 	TQString name(); //Name of the Plugin My Music .if TOM Create..Configure ..
-	TQString type(); //Type of the plugin ex: Application : Amork : kio ..etc
+	TQString type(); //Type of the plugin ex: Application : Amork : tdeio ..etc
 	uint id(); //A id for menus
 	KbfxDataGroup * search ( TQString str );
 //	KbfxPlasmaCanvasGroup * search(TQString _keyword,TQCanvas * canvas); //search and return a group
