@@ -61,7 +61,7 @@ KbfxSpinxScrollBar::paintEvent ( TQPaintEvent * pe )
 	p.drawPixmap ( TQRect ( 0, 0, m_normal.width (), m_normal.height () ),
 	               m_normal );
 	p.setPen ( TQColor ( 255,255,255 ) );
-	if ( m_pressed == false )
+	if ( !m_pressed )
 		p.setBrush ( TQColor ( 255,255,255 ) );
 	else
 		p.setBrush ( TQColor ( 0,0,0 ) );
