@@ -35,7 +35,7 @@
 class KbfxSpinxToolBar:public TQWidget
 {
 
-		Q_OBJECT
+		TQ_OBJECT
   
 	public:
 		KbfxSpinxToolBar ( TQWidget * parent = 0, const char * name = 0, WFlags f = 0 );
