@@ -43,7 +43,7 @@
 class KbfxSpinxToolButton:public TQLabel
 {
 
-		Q_OBJECT
+		TQ_OBJECT
   
 	public:
 		typedef enum{SINGLE=0,EXPANDABLE} ButtonType;
