@@ -36,7 +36,7 @@
 
 class KbfxSpinxTop:public TQWidget
 {
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
