@@ -27,7 +27,7 @@
 class KbfxSpinxView:public TQFrame
 {
 
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
