@@ -45,7 +45,7 @@
 class KbfxToolTip:public TQWidget
 {
 
-		Q_OBJECT
+		TQ_OBJECT
   
 	public:
 		KbfxToolTip ( TQWidget * parent=0,const char * name=0,WFlags fl=WType_TopLevel );
